@@ -909,6 +909,8 @@ int ipmi_cmdraw_ia(BYTE cmd, BYTE netfn, BYTE lun, BYTE sa, BYTE bus,
 #ifdef WIN32
    imbDev = "[imbdrv]";
    if (1) 
+#elif HPUX
+   imbDev = "/dev/ipmi";
 #else
    imbDev = "/dev/imb";
    if (stat(imbDev, &stbuf) == -1)  {
