@@ -108,7 +108,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 /*
  * Global variables 
  */
-static char * progver   = "2.96";
+static char * progver   = "2.97";
 static char * progname  = "ireset";
 static uchar  ipmi_maj;
 static uchar  ipmi_min;
@@ -410,7 +410,7 @@ static int IPMI_Reset(uchar bpower, uchar bootopt)
 		       responseData[0], responseData[1]);
                 }
 	if (status == ACCESS_OK && completionCode == 0) {
-		printf("chassis_reset ok\n");
+		printf("chassis_reset(%x) ok\n",bpower);
 		//successful, done
 		return(0);
 	} else if (fipmilan && (status < 0)) {
