@@ -162,7 +162,7 @@ typedef struct
 #define RDATA_OFFSET    13    //byte offset to the record event data  
 
 static char *progname  = "isel";
-static char *progver   = "2.96";
+static char *progver   = "2.97";
 #ifdef WIN32
 #define IDXFILE   "sel.idx"
 static char idxfile[80] = IDXFILE;
@@ -767,8 +767,9 @@ int i_sel(int argc, char **argv)
         ret = geteuid();
         if (ret > 1) {
             printf("Not superuser (%d)\n", ret);
-            ret = ERR_NOT_ALLOWED;
-	    goto do_exit;
+	    /* Show warning, but could be ok if /dev/ipmi0 is accessible */
+            //ret = ERR_NOT_ALLOWED;
+	    //goto do_exit;
         }
    }
 #endif
