@@ -98,7 +98,7 @@ int   gettimeofday(struct timeval *tv, struct timezone *tz);
 extern int verbose;
 extern char   fdebug;  /*from ipmicmd.c*/
 static char * progname  = "itsol";
-static char * progver   = "2.96";
+static char * progver   = "2.97";
 static uchar  g_bus  = PUBLIC_BUS;
 static uchar  g_sa   = BMC_SA;
 static uchar  g_lun  = BMC_LUN;
@@ -511,6 +511,11 @@ ipmi_tsol_main(void * intf, int  argc, char ** argv)
 	if (recvip != NULL)
 		result = ipmi_tsol_stop(intf, recvip, port);
 	return LAN_ERR_NOTSUPPORT;
+#elif defined(HPUX)
+	printf("HPUX TSOL terminal handling not yet implemented\n");
+	if (recvip != NULL)
+		result = ipmi_tsol_stop(intf, recvip, port);
+	return LAN_ERR_NOTSUPPORT;
 #else
 	/*
 	 * retrieve local IP address if not supplied on command line
