@@ -132,6 +132,7 @@ void lprintf(int level, const char * format, ...)
         static char logtmp[LOG_MSG_LENGTH];
 	FILE *fp = stderr; 
 	if (!verbose && (level > loglevel)) return;
+	if (level > LOG_WARN) fp = stdout; /*NOTICE,INFO*/
         if (fdbglog && (fplog != NULL)) fp = fplog;
 #ifdef WIN32
         va_start(vptr, format);
@@ -834,7 +835,7 @@ void WriteSyslog(char *msgbuf)
 	int level;
 	sev = find_msg_sev(msgbuf);
 	switch(sev) {
-	case SEV_MIN:  level = LOG_WARNING; break;
+	case SEV_MIN:  level = LOG_WARN; break;
 	case SEV_MAJ:  level = LOG_ERR; break;
 	case SEV_CRIT: level = LOG_CRIT; break;
 	case SEV_INFO: 
